@@ -10,9 +10,9 @@
 #include "simplemenu.h"
 
 #include <QTcpSocket>
+#include <QIcon>
 
 #include <KLocalizedString>
-#include <KIcon>
 
 #include "button.h"
 #include "chatwidget.h"
@@ -40,17 +40,14 @@ SimpleMenu::SimpleMenu(QWidget* parent, WelcomeScreen* screen)
 {
     if (m_screen) {    
         // create buttons
-        m_local_game_btn = m_screen->addButton(0, 0, KIcon( QLatin1String( iconLocal) ), i18n("Single Player" ));
-        m_server_btn = m_screen->addButton(0, 1, KIcon( QLatin1String( iconServer) ), i18n("Host Network Game" ));
-        m_client_btn = m_screen->addButton(0, 2, KIcon( QLatin1String( iconClient) ), i18n("Connect to Network Game" ));
+        m_local_game_btn = m_screen->addButton(0, 0, QIcon::fromTheme( QLatin1String( iconLocal) ), i18n("Single Player" ));
+        m_server_btn = m_screen->addButton(0, 1, QIcon::fromTheme( QLatin1String( iconServer) ), i18n("Host Network Game" ));
+        m_client_btn = m_screen->addButton(0, 2, QIcon::fromTheme( QLatin1String( iconClient) ), i18n("Connect to Network Game" ));
         
         // create connections
-        connect(m_local_game_btn, SIGNAL(clicked()),
-            this, SLOT(localGame()));
-        connect(m_server_btn, SIGNAL(clicked()),
-            this, SLOT(createServer()));
-        connect(m_client_btn, SIGNAL(clicked()),
-            this, SLOT(createClient()));
+        connect(m_local_game_btn, &Button::clicked, this, &SimpleMenu::localGame);
+        connect(m_server_btn, &Button::clicked, this, &SimpleMenu::createServer);
+        connect(m_client_btn, &Button::clicked, this, &SimpleMenu::createClient);
     }
 }
 
@@ -83,7 +80,7 @@ void SimpleMenu::createServer()
     }
 }
 
-void SimpleMenu::createClient(const KUrl& url)
+void SimpleMenu::createClientWithUrl(const QUrl& url)
 {
     QWidget* parent_widget = qobject_cast<QWidget*>(parent());
     Q_ASSERT(parent_widget);
@@ -104,7 +101,7 @@ void SimpleMenu::createClient()
 }
 
 void SimpleMenu::setupController(Controller* controller, Entity* old_opponent, SeaView* sea, 
-    ChatWidget* chat, bool ask)
+    ChatWidget* chat)
 {
     switch (m_state) {
     case DONE_LOCAL_GAME: {
@@ -154,8 +151,7 @@ void SimpleMenu::setupController(Controller* controller, Entity* old_opponent, S
         return;
     }
         
-    controller->start(sea, ask);
+    controller->start(sea);
 }
 
-#include "simplemenu.moc"
 
